Enum lpl_token_auth_rules::state::Key
source · #[repr(C)]
pub enum Key {
Uninitialized,
RuleSet,
Frequency,
}Expand description
The key at the beginning of the serialized account that identifies the account type.
NOTE: This is not used for the RuleSet account, which uses msgpack instead of Borsh for SerDes.
Variants
Uninitialized
An uninitialized account, which has all bytes set to zero by default.
RuleSet
An account containing a RuleSet.
Frequency
An account containing frequency state.