Struct lpl_token_auth_rules::state::FrequencyAccount
source · pub struct FrequencyAccount {
pub key: Key,
pub last_update: i64,
pub period: i64,
}Expand description
An account containing frequency state.
Fields
key: KeyThe Key for this account which identifies it as a Frequency account.
last_update: i64The last time the frequency counter was updated.
period: i64The period which must transpire before the rule will succeed again.
Implementations