Struct lpl_token_auth_rules::state::RuleSetHeader
source · pub struct RuleSetHeader {
pub key: Key,
pub rev_map_version_location: usize,
}Expand description
Header used to keep track of where RuleSets are stored in the PDA. This header is meant to be stored at the beginning of the PDA and never be versioned so that it always has the same serialized size. See top-level module for description of PDA memory layout.
Fields
key: KeyThe Key for this account which identifies it as a RuleSet account.
rev_map_version_location: usizeThe location of revision map version stored in the PDA. This is one byte before the revision map itself.
Implementations